=============================
django-glossa
=============================

.. image:: https://badge.fury.io/py/django-glossa.png
    :target: https://badge.fury.io/py/django-glossa

A glossary app for Django

Documentation
-------------

The full documentation is at https://django-glossa.readthedocs.org.

Quickstart
----------

Install django-glossa::

    pip install django-glossa

Then use it in a project::

    import glossario

Features
--------

* TODO

Cookiecutter Tools Used in Making This Package
----------------------------------------------

*  cookiecutter
*  cookiecutter-bitbucket-djangopackage
